All of lore.kernel.org
 help / color / mirror / Atom feed
From: Thomas Huth <thuth@redhat.com>
To: qemu-devel@nongnu.org
Cc: Stefan Hajnoczi <stefanha@redhat.com>,
	Nicholas Piggin <npiggin@gmail.com>
Subject: [PULL 08/10] tests/functional/test_ppc64_hv: Update to Alpine 3.21.0
Date: Thu,  2 Jan 2025 11:31:36 +0100	[thread overview]
Message-ID: <20250102103138.354618-9-thuth@redhat.com> (raw)
In-Reply-To: <20250102103138.354618-1-thuth@redhat.com>

From: Nicholas Piggin <npiggin@gmail.com>

Signed-off-by: Nicholas Piggin <npiggin@gmail.com>
Message-ID: <20241220024617.1968556-5-npiggin@gmail.com>
Signed-off-by: Thomas Huth <thuth@redhat.com>
---
 tests/functional/test_ppc64_hv.py | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/tests/functional/test_ppc64_hv.py b/tests/functional/test_ppc64_hv.py
index e0dffb1f15..62f996adf6 100755
--- a/tests/functional/test_ppc64_hv.py
+++ b/tests/functional/test_ppc64_hv.py
@@ -35,9 +35,9 @@ class HypervisorTest(QemuSystemTest):
     good_message = 'VFS: Cannot open root device'
 
     ASSET_ISO = Asset(
-        ('https://dl-cdn.alpinelinux.org/alpine/v3.18/'
-         'releases/ppc64le/alpine-standard-3.18.4-ppc64le.iso'),
-        'c26b8d3e17c2f3f0fed02b4b1296589c2390e6d5548610099af75300edd7b3ff')
+        ('https://dl-cdn.alpinelinux.org/alpine/v3.21/'
+         'releases/ppc64le/alpine-standard-3.21.0-ppc64le.iso'),
+        '7651ab4e3027604535c0b36e86c901b4695bf8fe97b908f5b48590f6baae8f30')
 
     def extract_from_iso(self, iso, path):
         """
@@ -114,7 +114,7 @@ def do_test_kvm(self, hpt=False):
                            '-initrd /media/nvme0n1/boot/initramfs-lts '
                            '-kernel /media/nvme0n1/boot/vmlinuz-lts '
                            '-append \'usbcore.nousb ' + append + '\'')
         # Alpine 3.18 kernel seems to crash in XHCI USB driver.
         ps1='localhost:~#'
         wait_for_console_pattern(self, 'localhost login:')
         exec_command_and_wait_for_pattern(self, 'root', ps1)
@@ -114,7 +114,7 @@ def do_test_kvm(self, hpt=False):
                            '-kernel /media/nvme0n1/boot/vmlinuz-lts '
                            '-append \'usbcore.nousb ' + append + '\'')
-        # Alpine 3.18 kernel seems to crash in XHCI USB driver.
+        # Alpine 3.21 kernel seems to crash in XHCI USB driver.
         ps1='localhost:~#'
         wait_for_console_pattern(self, 'localhost login:')
-- 
2.47.1



  parent reply	other threads:[~2025-01-02 10:32 UTC|newest]

Thread overview: 12+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2025-01-02 10:31 [PULL 00/10] Functional test improvements and fixes Thomas Huth
2025-01-02 10:31 ` [PULL 01/10] docs: update copyright date to the year 2025 Thomas Huth
2025-01-02 10:31 ` [PULL 02/10] tests/functional: Convert the vnc test Thomas Huth
2025-01-02 10:31 ` [PULL 03/10] tests/functional/test_vnc: Do not use a hard-coded VNC port Thomas Huth
2025-01-02 10:31 ` [PULL 04/10] tests/functional/test_vnc: Remove the test_no_vnc test Thomas Huth
2025-01-02 10:31 ` [PULL 05/10] tests/functional: Extract the find_free_ports() function into a helper file Thomas Huth
2025-01-02 10:31 ` [PULL 06/10] tests/functional/test_ppc64_hv: Simplify console handling Thomas Huth
2025-01-02 10:31 ` [PULL 07/10] tests/functional/test_ppc64_hv: Update repo management Thomas Huth
2025-01-02 10:31 ` Thomas Huth [this message]
2025-01-02 10:31 ` [PULL 09/10] tests/functional/test_rx_gdbsim: Use stable URL for test_linux_sash Thomas Huth
2025-01-02 10:31 ` [PULL 10/10] tests/functional/test_arm_quanta_gsj: Fix broken test Thomas Huth
2025-01-03  0:52 ` [PULL 00/10] Functional test improvements and fixes Stefan Hajnoczi

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20250102103138.354618-9-thuth@redhat.com \
    --to=thuth@redhat.com \
    --cc=npiggin@gmail.com \
    --cc=qemu-devel@nongnu.org \
    --cc=stefanha@redhat.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.